==> dimlpfidex-0.0.0.tar.gz: dimlpfidex-0.0.0/dimlp/cpp/src/dimlp.cpp <==
#include "dimlp.h"
using namespace std;

////////////////////////////////////////////////////////////////////////
const char netType[] = "Discretized Interpretable Multi-Layer Perceptron";

Dimlp::Dimlp(
    float eta,
    float mu,
    float flat,
    float errParam,
    float accuracyParam,
    float deltaErrParam,
    int discrLevels,
    int showErrParam,
    int nbEpochsParam,
    int nbLayers,
    const std::vector<int> &nbNeurons,
    const char weightFile[],
    int seed) :

                BpNN(eta, mu, flat, errParam, accuracyParam, deltaErrParam,
                     showErrParam, nbEpochsParam, nbLayers, nbNeurons, weightFile,
                     netType, seed)

{
  cout << "Number of quantized levels = " << discrLevels << "\n"
       << endl;

  DefineDimlp(discrLevels);
}

////////////////////////////////////////////////////////////////////////

Dimlp::Dimlp(
    const char readFile[],
    int nbLayers,
    const std::vector<int> &nbNeurons,
    int discrLevels) :

                       BpNN(readFile, nbLayers, nbNeurons,
                            netType)

{
  cout << "Number of quantized levels = " << discrLevels << "\n"
       << endl;

  DefineDimlp(discrLevels);
  ReadWeights();
}

////////////////////////////////////////////////////////////////////////

Dimlp::Dimlp(
    const char readFile[],
    float eta,
    float mu,
    float flat,
    float errParam,
    float accuracyParam,
    float deltaErrParam,
    int discrLevels,
    int showErrParam,
    int nbEpochsParam,
    int nbLayers,
    const std::vector<int> &nbNeurons,
    const char weightFile[],
    int seed) :

                BpNN(readFile, eta, mu, flat, errParam, accuracyParam, deltaErrParam,
                     showErrParam, nbEpochsParam, nbLayers, nbNeurons, weightFile,
                     netType, seed) {
  cout << "Number of quantized levels = " << discrLevels << "\n"
       << endl;

  DefineDimlp(discrLevels);
  ReadWeights();
}

////////////////////////////////////////////////////////////////////////

==> dimlpfidex-0.0.1.tar.gz: dimlpfidex-0.0.1/dimlp/cpp/src/dimlp.cpp <==
#include "dimlp.h"

////////////////////////////////////////////////////////////////////////
const std::string &netType = "Discretized Interpretable Multi-Layer Perceptron";

Dimlp::Dimlp(
    float eta,
    float mu,
    float flat,
    float errParam,
    float accuracyParam,
    float deltaErrParam,
    int discrLevels,
    int showErrParam,
    int nbEpochsParam,
    int nbLayers,
    const std::vector<int> &nbNeurons,
    const std::string &weightFile,
    int seed) :

                BpNN(eta, mu, flat, errParam, accuracyParam, deltaErrParam,
                     showErrParam, nbEpochsParam, nbLayers, nbNeurons, weightFile,
                     netType, seed)

{
  std::cout << "Number of quantized levels = " << discrLevels << "\n"
            << std::endl;

  DefineDimlp(discrLevels);
}

////////////////////////////////////////////////////////////////////////

Dimlp::Dimlp(
    const std::string &readFile,
    int nbLayers,
    const std::vector<int> &nbNeurons,
    int discrLevels,
    int netId) :

                 BpNN(readFile, nbLayers, nbNeurons,
                      netType, netId)

{
  std::cout << "Number of quantized levels = " << discrLevels << "\n"
            << std::endl;

  DefineDimlp(discrLevels);
  ReadWeights();
}

////////////////////////////////////////////////////////////////////////

Dimlp::Dimlp(
    const std::string &readFile,
    float eta,
    float mu,
    float flat,
    float errParam,
    float accuracyParam,
    float deltaErrParam,
    int discrLevels,
    int showErrParam,
    int nbEpochsParam,
    int nbLayers,
    const std::vector<int> &nbNeurons,
    const std::string &weightFile,
    int seed) :

                BpNN(readFile, eta, mu, flat, errParam, accuracyParam, deltaErrParam,
                     showErrParam, nbEpochsParam, nbLayers, nbNeurons, weightFile,
                     netType, seed) {
  std::cout << "Number of quantized levels = " << discrLevels << "\n"
            << std::endl;

  DefineDimlp(discrLevels);
  ReadWeights();
}

////////////////////////////////////////////////////////////////////////
